@@ -1,6 +1,5 @@
 use crate::core::ribosome::CallContext;
 use crate::core::ribosome::RibosomeT;
-use holo_hash::HasHash;
 use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use std::sync::Arc;
@@ -14,13 +13,10 @@ pub fn zome_info(
     match HostFnAccess::from(&call_context.host_context()) {
         HostFnAccess{ bindings_deterministic: Permission::Allow, .. } => {
             Ok(ZomeInfo {
-                dna_name: ribosome.dna_def().name.clone(),
-                zome_name: call_context.zome.zome_name().clone(),
-                dna_hash: ribosome.dna_def().as_hash().clone(),
-                zome_id: ribosome
+                name: call_context.zome.zome_name().clone(),
+                id: ribosome
                     .zome_to_id(&call_context.zome)
                     .expect("Failed to get ID for current zome"),
-                properties: ribosome.dna_def().properties.clone(),
                 // @TODO
                 // public_token: "".into(),
             })
@@ -42,6 +38,6 @@ pub mod test {
         let host_access = fixt!(ZomeCallHostAccess, Predictable);
         let zome_info: ZomeInfo =
             crate::call_test_ribosome!(host_access, TestWasm::ZomeInfo, "zome_info", ()).unwrap();
-        assert_eq!(zome_info.dna_name, "test",);
+        assert_eq!(zome_info.name, "zome_info".into());
     }
 }
