@@ -3,6 +3,7 @@ use crate::conductor::api::CellConductorApiT;
 use crate::core::ribosome::guest_callback::init::InitHostAccess;
 use crate::core::ribosome::guest_callback::init::InitInvocation;
 use crate::core::ribosome::guest_callback::init::InitResult;
+use crate::core::ribosome::guest_callback::post_commit::send_post_commit;
 use crate::core::ribosome::RibosomeT;
 use derive_more::Constructor;
 use holochain_keystore::MetaLairClient;
@@ -16,7 +17,7 @@ use tracing::*;
 pub struct InitializeZomesWorkflowArgs<Ribosome, C>
 where
     Ribosome: RibosomeT + Send + 'static,
-    C: CellConductorApiT,
+    C: CellConductorApiT + Clone,
 {
     pub dna_def: DnaDef,
     pub ribosome: Ribosome,
@@ -34,14 +35,17 @@ where
     Ribosome: RibosomeT + Send + 'static,
     C: CellConductorApiT,
 {
+    let conductor_api = args.conductor_api.clone();
     let result =
-        initialize_zomes_workflow_inner(workspace.clone(), network.clone(), keystore, args).await?;
+        initialize_zomes_workflow_inner(workspace.clone(), network.clone(), keystore.clone(), args)
+            .await?;
 
     // --- END OF WORKFLOW, BEGIN FINISHER BOILERPLATE ---
 
     // only commit if the result was successful
     if result == InitResult::Pass {
-        workspace.flush(&network).await?;
+        let flushed_headers = workspace.clone().flush(&network).await?;
+        send_post_commit(conductor_api, workspace, network, keystore, flushed_headers).await?;
     }
     Ok(result)
 }
@@ -75,6 +79,7 @@ where
     tokio::task::spawn(async move {
         ws.source_chain()
             .put(
+                None,
                 builder::InitZomesComplete {},
                 None,
                 ChainTopOrdering::Strict,
